*** War Inequality and Taxation - Replication Package ***
** Dalton Dorr & Adrian Shin **
***************************************************************
***************************************************************
use "War Inequality and Taxation - Cross National.dta"


**** Cross-National Analyses ****


/** Table 2 **/
*** Inheritance Tax Rate 1-Year Lag and Using Top 1% and 10% Income Share ***

** Without the Interaction and Top 1% (original sample) **
/* Model 1 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

** Without the Interaction and Top 1% (only observations with non-missing top 1% income-share values) **
/* Model 2 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

** With the Interaction and Top 1% **
/* Model 3 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure 3a */
qui margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top1isl1 if top1isl1<22 & top1isl1>4 & warl1!=. & topitaxrate2l1!=., yaxis(2) xscale(range(4(2)22)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(4(2)22)) recast(line) yline(0) xtitle(Top 1% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure 4a */
qui margins, dydx(top1isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

** With the Interaction and Top 10% **
/* Model 4 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure 3b */
qui margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10isl1 if top10isl1<48 & top10isl1>24 & warl1!=. & topitaxrate2l1!=., yaxis(2) xscale(range(24(2)48)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .12) off) lc(ltblue) fcolor(none) xlabel(24(2)48)) recast(line) yline(0) xtitle(Top 10% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure 4b */
qui margins, dydx(top10isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))



/* Table 3 */
*** Income Tax Rate 1-Year Lag and Using Top 1% and 10% Income Share ***

** Without the Interaction and Top 1% (original sample) **
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

** Without the Interaction and Top 1% (only observations with non-missing top 1% income-share values) **
/* Model 5 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

** With the Interaction and Top 1% **
/* Model 6 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure 5a */
qui margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top1isl1 if top1isl1<22 & top1isl1>4 & warl1!=. & top_incrate_nl1!=., yaxis(2) xscale(range(4(2)22)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(4(2)22)) recast(line) yline(0) xtitle(Top 1% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure 6a */
qui margins, dydx(top1isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title(Marginal Effects of Inequality with 95% CIs) ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

** With the Interaction and Top 10% **
/* Model 7 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year i.ccode  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure 5b */
qui margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10isl1 if top10isl1<48 & top10isl1>24 & warl1!=. & top_incrate_nl1!=., yaxis(2) xscale(range(24(2)48)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .12) off) lc(ltblue) fcolor(none) xlabel(24(2)48)) recast(line) yline(0) xtitle(Top 10% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure 6b */
qui margins, dydx(top10isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-1.4(.4).2)) yline(0) ylabel(-1.4(.4).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title(Marginal Effects of Inequality with 95% CIs) ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))



*** Time Series Figures ***
gen temp=100
gen temp2=0

** Top 1% Income Share **
** Australia **
twoway (rarea temp temp2 year if ccode==900 & year>=1915 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==900 & year>=1941 & year<=1945, bcolor(gs13)) (line topitaxrate2 year if ccode==900 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==900 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==900 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)), xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("Australia" , size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 3 4 5) lab(1 "WWI & WWII") lab(3 "Top Rate (Inheritance)") lab(4 "Top Rate (Income)") lab(5 "Top 1% Income Share")region(lcolor(white))) pcycle(1)
graph save ts_panel_australia_top1is2,replace

** Canada **
twoway (rarea temp temp2 year if ccode==20 & year>=1915 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==20 & year>=1941 & year<=1945, bcolor(gs13)) (line topitaxrate2 year if ccode==20 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==20 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==20 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)), xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("Canada" , size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 3 4 5) lab(1 "WWI & WWII") lab(3 "Top Rate (Inheritance)") lab(4 "Top Rate (Income)") lab(5 "Top 1% Income Share")region(lcolor(white))) pcycle(1)
graph save ts_panel_canada_top1is2,replace

** France **
twoway (rarea temp temp2 year if ccode==220 & year>=1914 & year<=1920, bcolor(gs13)) (rarea temp temp2 year if ccode==220 & year>=1940 & year<=1941, bcolor(gs13)) (line topitaxrate2 year if ccode==220 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==220 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==220 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)), xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("France" , size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 3 4 5) lab(1 "WWI & WWII") lab(3 "Top Rate (Inheritance)") lab(4 "Top Rate (Income)") lab(5 "Top 1% Income Share")region(lcolor(white))) pcycle(1)
graph save ts_panel_france_top1is2,replace

** Germany **
/* Figure 8 */
twoway (rarea temp temp2 year if ccode==255 & year>=1915 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==255 & year>=1939 & year<=1945, bcolor(gs13)) (line topitaxrate2 year if ccode==255 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==255 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==255 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) ytitle("Top 1% Income Share", axis(2)) lwidth(medthick) lpattern(dash)), ytitle(Tax Rate (Percent), height(5)) xtitle(Year) xlabel(1850(50)2000) title("") subtitle("Germany") graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 3 4 5) lab(1 "WWI & WWII") lab(3 "Top Rate (Inheritance)") lab(4 "Top Rate (Income)") lab(5 "Top 1% Income Share")region(lcolor(white)) ) pcycle(1)
graph save ts_panel_germany_top1is,replace
graph export ts_panel_germany_top1is.pdf, replace

* For Figure 2 *
twoway (rarea temp temp2 year if ccode==255 & year>=1915 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==255 & year>=1939 & year<=1945, bcolor(gs13)) (line topitaxrate2 year if ccode==255 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==255 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==255 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)), xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("Germany" , size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 3 4 5) lab(1 "WWI & WWII") lab(3 "Top Rate (Inheritance)") lab(4 "Top Rate (Income)") lab(5 "Top 1% Income Share")region(lcolor(white))) pcycle(1)
graph save ts_panel_germany_top1is2,replace

** Japan **
twoway (rarea temp temp2 year if ccode==740 & year>=1941 & year<=1945, bcolor(gs13)) (line topitaxrate2 year if ccode==740 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==740 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==740 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)), xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("Japan", size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 2 3 4) lab(1 "WWII") lab(2 "Top Rate (Inheritance)") lab(3 "Top Rate (Income)") lab(4 "Top 1% Income Share")region(lcolor(white)) ) pcycle(1)
graph save ts_panel_japan_top1is2,replace

** USA **
/* Figure 7 */
twoway (rarea temp temp2 year if ccode==2 & year>=1918 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==2 & year>=1939 & year<=1945, bcolor(gs13)) (rarea temp temp2 year if ccode==2 & year>=1951 & year<=1953, bcolor(gs13)) (line topitaxrate2 year if ccode==2 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==2 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==2 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) ytitle("Top 1% Income Share", axis(2))  lwidth(medthick) lpattern(dash)), ytitle(Tax Rate (Percent), height(5)) xtitle(Year) xlabel(1850(50)2000) title("") subtitle("United States") graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 4 5 6) lab(1 "WWII & Korean War") lab(4 "Top Rate (Inheritance)") lab(5 "Top Rate (Income)") lab(6 "Top 1% Income Share")region(lcolor(white)) ) pcycle(1)
graph save ts_panel_usa_top1is,replace
graph export ts_panel_usa_top1is.pdf, replace

* For Figure 2 *
twoway (rarea temp temp2 year if ccode==2 & year>=1918 & year<=1918, bcolor(gs13)) (rarea temp temp2 year if ccode==2 & year>=1939 & year<=1945, bcolor(gs13)) (rarea temp temp2 year if ccode==2 & year>=1951 & year<=1953, bcolor(gs13)) (line topitaxrate2 year if ccode==2 & year>=1816, lwidth(medthick) lpattern(solid)) (line top_incrate_n year if ccode==2 & year>=1816, lwidth(medthick) lpattern(solid) lc(gs10)) (line top1is year if ccode==2 & year>=1816, yaxis(2) yscale(axis(2) range(0 25)) ylabel(0(5)25,axis(2)) lwidth(medthick) lpattern(dash)),  xtitle("") ytitle("") ytitle("", axis(2)) xlabel(1850(50)2000) title("") subtitle("United States", size(vlarge)) graphregion(fcolor(white) lcolor(white)) legend(row(2) order(1 4 5 6) lab(1 "Mobilized for War") lab(4 "Top Rate (Inheritance)") lab(5 "Top Rate (Income)") lab(6 "Top 1% Income Share")region(lcolor(white))) pcycle(1)
graph save ts_panel_usa_top1is2,replace

/* Figure 2 */
grc1leg ts_panel_australia_top1is2.gph ts_panel_canada_top1is2.gph ts_panel_france_top1is2.gph ts_panel_germany_top1is2.gph ts_panel_japan_top1is2.gph ts_panel_usa_top1is2.gph,  col(2) ycommon graphregion(fcolor(white) lcolor(white))  altshrink title("") subtitle("", size(1))  l1("Tax Rate (Percent)", size(small)) b1("Year", size(small)) r1("Top 1% Income Share", size(small)) legendfrom(ts_panel_usa_top1is2.gph)
graph save FigureCombinedTop1,replace
graph display, ysize(6) xsize(4)
graph export FigureCombinedTop1.pdf, replace



/* Table A5 */
*** No War in Current Period ***

/* Model A1 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1##himobpopyear2p unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure A1a */
margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22) himobpopyear2p=(0 1))
marginsplot, xsize(4) ysize(6) recast(line) yline(0) xtitle(Top 1% Share of Income, size(med)) title("") ytitle("") graphregion(fcolor(white) lcolor(white)) legend(row(2)) plot(,label("Not Mobilized for War"  "Mobilized for War"))

/* Model A2 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1##c.himobpopyear2p unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure A2b */
margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48) himobpopyear2p=(0 1))
marginsplot, xsize(4) ysize(6) recast(line) yline(0) xtitle(Top 10% Share of Income, size(med)) title("") ytitle("") graphregion(fcolor(white) lcolor(white)) legend(row(2)) plot(,label("Not Mobilized for War"  "Mobilized for War"))

/* Model A3 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1##c.himobpopyear2p unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure A2c */
margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22) himobpopyear2p=(0 1))
marginsplot, xsize(4) ysize(6) recast(line) yline(0) xtitle(Top 1% Share of Income, size(med)) title("") ytitle("") graphregion(fcolor(white) lcolor(white)) legend(row(2)) plot(,label("Not Mobilized for War"  "Mobilized for War"))

/* Model A4 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1##c.himobpopyear2p unisuffragel1 leftexec2l1 rgdppcl1 i.year i.ccode  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure A2d */
margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48) himobpopyear2p=(0 1))
marginsplot, xsize(4) ysize(6) recast(line) yline(0) xtitle(Top 10% Share of Income, size(med)) title("") ytitle("") graphregion(fcolor(white) lcolor(white)) legend(row(2)) plot(,label("Not Mobilized for War"  "Mobilized for War"))


/* Table A7 */
*** Income Tax Rate 1-Year Lag and Using Top 1% Income Share when Top 10% Income Share is Non-Missing ***

/* Model A5 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top10isl1!=.



/* Table A8 */
*** Top 1% Income Share Regressed on War Mobilization ***

** 2% War Mobilization and Top 1% Income Share without YFE **
/* Model A6 */
xtreg top1is top1isl1 himobpopyear2pl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** 2% War Mobilization Top 1% Income Share with YFE ** 
/* Model A7 */
xtreg top1is top1isl1 himobpopyear2pl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Population Share and Top 1% Income Share without YFE **
/* Model A8 */
xtreg top1is top1isl1 mobpophifatwarl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Population Share and Top 1% Income Share with YFE **
/* Model A9 */
xtreg top1is top1isl1 mobpophifatwarl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** World Warsand Top 1% Income Share without YFE **
/* Model A10 */
xtreg top1is top1isl1 wwi_iihighmob3l1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** World Wars and Top 1% Income Share with YFE **
/* Model A11 */
xtreg top1is top1isl1 wwi_iihighmob3l1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

/* Table A9 */
*** Top 10% Income Share Regressed on War Mobilization ***

** 2% War Mobilization and Top 10% Income Share without YFE **
/* Model A12 */
xtreg top10peris top10isl1 himobpopyear2pl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** 2% War Mobilization Top 10% Income Share with YFE ** 
/* Model A13 */
xtreg top10peris top10isl1 himobpopyear2pl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Population Share and Top 10% Income Share without YFE **
/* Model A14 */
xtreg top10peris top10isl1 mobpophifatwarl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Population Share and Top 10% Income Share with YFE **
/* Model A15 */
xtreg top10peris top10isl1 mobpophifatwarl1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** World Wars and Top 10% Income Share without YFE **
/* Model A16 */
xtreg top10peris top10isl1 wwi_iihighmob3l1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** World Wars and Top 10% Income Share with YFE **
/* Model A17 */
xtreg top10peris top10isl1 wwi_iihighmob3l1 unisuffragel1 polity2l1 leftexec2l1 rgdppcl1 ln_popl1 i.ccode i.year  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)



/* Table A10 */
*** Inheritance and Income Tax Rate 1-Year Lag and Using Top 10% minus 1% Income Share ***

** Inheritance Tax **

/* Model A18 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10_1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A2a */
qui margins, dydx(himobpopyear2pl1) at(top10_1isl1=(16(2)32)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10_1isl1 if top10_1isl1<32 & top10_1isl1>16 & warl1!=. & topitaxrate2l1!=., yaxis(2) xscale(range(16(2)32)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(16(2)32)) recast(line) yline(0) xtitle(Next Nine Percentiles Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A2c */
qui margins, dydx(top10_1isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))


** Income Tax **

/* Model A19 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10_1isl1  unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A2b */
qui margins, dydx(himobpopyear2pl1) at(top10_1isl1=(16(2)32)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10_1isl1 if top10_1isl1<32 & top10_1isl1>16 & warl1!=. & topitaxrate2l1!=., yaxis(2) xscale(range(16(2)32)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(16(2)32)) recast(line) yline(0) xtitle(Next Nine Percentiles Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A2d */
qui margins, dydx(top10_1isl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))



/* Table A11 */
*** Tables 1 & 2 without LDV ***

/* Model A20 */
xtpcse  topitaxrate2 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A21 */
xtpcse  topitaxrate2 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A22 */
xtpcse  topitaxrate2 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A23 */
xtpcse  topitaxrate2 c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A24 */
xtpcse  top_incrate_n c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A25 */
xtpcse  top_incrate_n c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A26 */
xtpcse  top_incrate_n c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year i.ccode  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 



/* Table A12 */
*** Tables 1 & 2 without CFE ***

/* Model A27 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A28 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A29 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A30 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A31 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A32 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A33 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 



/* Table A13 */
*** Tables 1 & 2 with POLITY ***

/* Model A34 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A35 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A36 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A37 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A38 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top1isl1!=.

/* Model A39 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A40 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1 polity2l1 leftexec2l1 rgdppcl1 i.year i.ccode australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 



/* Table A14 */
*** Inheritance and Income Tax Rates 1-Year Lag Using Top 5% Income Share ***

/* Model A41 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top5isl1!=.

/* Model A42 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top5isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Model A43 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & top5isl1!=.

/* Model A44 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top5isl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 



/* Table A15 */
*** Inheritance and Income Tax Rate 1-Year Lag and Using Top 1% and 10% Wealth Shares ***

** Top 1% Wealth Shares & Inheritance Tax **
/* Model A45 */
xtreg topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1wsl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Top 10% Wealth Shares & Inheritance Tax **
/* Model A46 */
xtreg topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10wsl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

** Top 1% Wealth Shares & Income Tax **
/* Model A47 */
xtreg top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1wsl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

* Marginal Effect of War * 
/* Figure A3a */
qui margins, dydx(himobpopyear2pl1) at(top1wsl1=(15(5)70)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top1wsl1 if top1wsl1<70 & top1wsl1>15 & warl1!=. & top_incrate_nl1!=., yaxis(2) xscale(range(15(5)70)) yscale(range(0(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(15(5)70)) recast(line) yline(0) xtitle(Top 1% Share of Wealth, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

** Marginal Effect of Inequality **
/* Figure A3c */
qui margins, dydx(top1wsl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

** Top 10% Wealth Shares & Income Tax **
/* Model A48 */
xtreg top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10wsl1 unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1, cluster(ccode)

* Marginal Effect of War *
/* Figure A3b */
qui margins, dydx(himobpopyear2pl1) at(top10wsl1=(45(5)90)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10wsl1 if top10wsl1<90 & top10wsl1>45 & warl1!=. & top_incrate_nl1!=., yaxis(2) xscale(range(45(5)90)) yscale(range(0(.1)1)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(45(5)90)) recast(line) yline(0) xtitle(Top 10% Share of Wealth, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A3d */
qui margins, dydx(top10wsl1) at(himobpopyear2pl1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist himobpopyear2pl1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) xlabel(0 "Not Mobilized" 1 "Mobilized") yscale(axis(1) range(-.6(.2).2)) yline(0) ylabel(-.6(.2).2,axis(1)) xscale(range(-.25 1.25)) barwidth(.25)) recast(scatter) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))



*** Interactions with Universal Suffrage ***

** Inheritance Tax and Top 1% Income Share **
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1##i.unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A4a */
qui margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) ytitle("") title("") xtitle("Top 1% Income Share (t-1)") legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A5a */
qui margins, dydx(top1isl1) at(himobpopyear2pl1=(0 1) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) recast(scatter) ytitle("") title("")  xlab(0 "Not Mobilized" 1 "Mobilized") xscale(range(-0.5 1.5)) legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

** Inheritance Tax and Top 10% Income Share **
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1##i.unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A4b */
qui margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) ytitle("") title("") xtitle("Top 10% Income Share (t-1)") legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A5b */
qui margins, dydx(top10isl1) at(himobpopyear2pl1=(0 1) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) recast(scatter) ytitle("") xlab(0 "Not Mobilized" 1 "Mobilized") xscale(range(-0.5 1.5)) title("")  legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

** Income Tax and Top 1% Income Share **
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1##i.unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A4c */
qui margins, dydx(himobpopyear2pl1) at(top1isl1=(4(2)22) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) ytitle("") title("") xtitle("Top 1% Income Share (t-1)") legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A5c */
qui margins, dydx(top1isl1) at(himobpopyear2pl1=(0 1) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) recast(scatter) ytitle("") title("") xlab(0 "Not Mobilized" 1 "Mobilized") xscale(range(-0.5 1.5)) legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

** Income Tax and Top 10% Income Share **
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1##i.unisuffragel1 leftexec2l1 rgdppcl1 i.year i.ccode  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

* Marginal Effect of War *
/* Figure A4d */
qui margins, dydx(himobpopyear2pl1) at(top10isl1=(24(2)48) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) ytitle("") title("") xtitle("Top 10% Income Share (t-1)") legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))

* Marginal Effect of Inequality *
/* Figure A5d */
qui margins, dydx(top10isl1) at(himobpopyear2pl1=(0 1) unisuffragel1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) plot1opts(color(gs11)) ci1opts(lc(gs11)) plot2opts(color(black)) ci2opts(lc(black)) yline(0) recast(scatter) ytitle("") title("") xlab(0 "Not Mobilized" 1 "Mobilized") xscale(range(-0.5 1.5)) legend(row(2) order (1 2) lab(1 "No Universal Suffrage") lab(2 "Universal Suffrage") region(lcolor(white))) graphregion(fcolor(white) lcolor(white))



/* Table A16 */
*** Life Expectancy ***

** Inheritance Tax and Top 1% Income Share **
/* Model A53 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top1isl1 lifeexpectancyyears unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

** Inheritance Tax and Top 10% Income Share **
/* Model A54 */
xtpcse  topitaxrate2 topitaxrate2l1 c.himobpopyear2pl1##c.top10isl1 lifeexpectancyyears unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

** Income Tax and Top 1% Income Share **
/* Model A55 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top1isl1 lifeexpectancyyears unisuffragel1 leftexec2l1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

** Income Tax and Top 10% Income Share **
/* Model A56 */
xtpcse  top_incrate_n top_incrate_nl1 c.himobpopyear2pl1##c.top10isl1 lifeexpectancyyears unisuffragel1 leftexec2l1 rgdppcl1 i.year i.ccode  australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 



/* Table A17 */
*** Upper Chamber Veto ***

** Upper Chamber Veto with Top 1% Income Share **
/* Model A49 */
probit upper upperl1 top1isl1 unisuffragel1 leftexec2l1 rgdppcl1 top1isl1Xupperl1 unisuffragel1Xupperl1 leftexec2l1Xupperl1 rgdppcl1Xupperl1 i.hdecadec, cluster(ccode)

** Upper Chamber Veto with Top 10% Income Share **
/* Model A50 */
probit upper upperl1 top10isl1 unisuffragel1 leftexec2l1 rgdppcl1 top10isl1Xupperl1 unisuffragel1Xupperl1 leftexec2l1Xupperl1 rgdppcl1Xupperl1, cluster(ccode)



/* Table A18 */
*** Left/Right Executive ***

** Left Executive and Top 10% Income Share **
/* Model A57 */
probit leftexec2 leftexec2l1 top10isl1 himobpopyear2pl1 rgdppcl1 top10isl1Xleftexec2l1 himobpopyear2pl1Xleftexec2l1 rgdppcl1Xleftexec2l1 i.hdecadec, cluster(ccode)

** Left Executive and Top 1% Income Share **
/* Model A58 */
probit leftexec2 leftexec2l1 top1isl1 himobpopyear2pl1 rgdppcl1 top1isl1Xleftexec2l1 himobpopyear2pl1Xleftexec2l1 rgdppcl1Xleftexec2l1 i.hdecadec, cluster(ccode)

** Non-Left Executive and Top 10% Income Share **
/* Model A59 */
probit rightexec rightexecl1 top10isl1 himobpopyear2pl1 rgdppcl1 top10isl1Xrightexecl1 himobpopyear2pl1Xrightexecl1 rgdppcl1Xrightexecl1 i.hdecadec, cluster(ccode)

** Non-Left Executive and Top 1% Income Share **
/* Model A60 */
probit rightexec rightexecl1 top1isl1 himobpopyear2pl1 rgdppcl1 top1isl1Xrightexecl1 himobpopyear2pl1Xrightexecl1 rgdppcl1Xrightexecl1 i.hdecadec, cluster(ccode)






***************************************************************
***************************************************************

**** U.S. Senate Analyses ****
clear
use "War Inequality and Taxation - US Senate.dta"



/* Table 4 */
*** U.S. Senate Voting ***

** Top 10% Income Share and Abstentions as Missing **
/* Model 8 */
logit vote_miss c.top10is##c.mobrate republican congress_num i_foreignborn i_population ln_farms i.state i.year, cluster(state)

* Marginal Effect of War *
/* Figure 9a */
margins, dydx(mobrate) at(top10is=(10(5)70))
marginsplot, xsize(4) ysize(6) addplot(hist top10is if top10is<70 & top10is>10, yaxis(2) xscale(range(10(5)70)) yscale(range(-.03(.01).01)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(10(5)70)) recast(line) yline(0) xtitle(Top 10% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))


** Top 1% Income Share and Abetentions as Missing **
/* Model 9 */
logit vote_miss c.top1is##c.mobrate republican congress_num i_foreignborn i_population ln_farms i.state i.year, cluster(state)

* Marginal Effects of War *
/* Figure 9b */
margins, dydx(mobrate) at(top1is=(1(5)51))
marginsplot, xsize(4) ysize(6) addplot(hist top1is if top1is<51 & top1is>1, yaxis(2) xscale(range(1(5)51)) yscale(range(-.03(.01).01)) yscale(axis(2) range(0 .21) off) lc(ltblue) fcolor(none) xlabel(1(5)51)) recast(line) yline(0) xtitle(Top 1% Share of Income, size(med)) title("") ytitle("") legend(off) graphregion(fcolor(white) lcolor(white))



***************************************************************
***************************************************************


